/* Perfectspot - Wordperfect Graphics viewer
 * Copyright (C) 2007 Ariya Hidayat (ariya@kde.org)
 * Copyright (C) 2006 Ariya Hidayat (ariya@kde.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA
 *
 */

/* "This product is not manufactured, approved, or supported by
 * Corel Corporation or Corel Corporation Limited."
 */

#ifndef CANVAS_H
#define CANVAS_H

#include <QLabel>
#include <QFrame>
#include <QPoint>
#include <QPixmap>
#include <QString>
#include <QWidget>

class QKeyEvent;
class QMouseEvent;
class QPaintEvent;
class QWheelEvent;
class QResizeEvent;

// enable smooth zoom and rotate only on Qt 4.2 or later
#if QT_VERSION >= 0x040200
#define SMOOTH_ZOOM
#define SMOOTH_ROTATE
class QTimeLine;
#else
#undef SMOOTH_ZOOM
#undef SMOOTH_ROTATE
#endif

class Renderer;

class View : public QFrame
{
	Q_OBJECT

public:
	View(QWidget *parent);
	QSizeF graphicsSize() const;
	void openFile(const QString &file);

	// zoom level in percentage, e.g. 100 for 100%
	int zoomLevel() const;

	// rotation angle (in degree)
	int rotation() const;

	bool exportGraphics(const QString &file);

public slots:
	void zoomIn();
	void zoomOut();
	void setZoomLevel(int z);
	void rotateLeft();  // counter-clockwise
	void rotateRight(); // clockwise
	void setRotation(int a);

private slots:
	void doZoom(int z);
	void doRotate(int z);
	void hideInfo();

protected:
	void updateContent();
	void adjustMargins();
	void paintEvent(QPaintEvent *event);
	void mousePressEvent(QMouseEvent *event);
	void mouseMoveEvent(QMouseEvent *event);
	void mouseReleaseEvent(QMouseEvent *event);
	void resizeEvent(QResizeEvent *event);

private:
	double zoom;
	double angle;
	double renderAngle;
	QRect graphicsRect;
	Renderer *renderer;
	QPixmap buffer;
	QString info;

	QPoint mousePressPos;
	QPoint graphicsPos;
	QString currentPath;
#ifdef SMOOTH_ZOOM
	QTimeLine *zoomTimeLine;
#endif
#ifdef SMOOTH_ROTATE
	QTimeLine *rotateTimeLine;
#endif
};

#endif // CANVAS_H
