/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
/* writerperfect
 * Version: MPL 2.0 / LGPLv2.1+
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * Major Contributor(s):
 * Copyright (C) 2007 Fridrich Strba (fridrich.strba@bluewin.ch)
 *
 * For minor contributions see the git repository.
 *
 * Alternatively, the contents of this file may be used under the terms
 * of the GNU Lesser General Public License Version 2.1 or later
 * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
 * applicable instead of those above.
 *
 * For further information visit http://libwpd.sourceforge.net
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdio.h>

#include "OutputFileHelper.h"
#include "FemtoZip.h"

struct OutputFileHelperImpl
{
	OutputFileHelperImpl() : mpOutfile(0) {}
	FemtoZip *mpOutfile;
private:
	OutputFileHelperImpl(OutputFileHelperImpl const &);
	OutputFileHelperImpl &operator=(OutputFileHelperImpl const &);
};


OutputFileHelper::OutputFileHelper(const char *outFileName) :
	m_impl(new OutputFileHelperImpl())
{
	m_impl->mpOutfile = 0;
	if (outFileName)
		m_impl->mpOutfile = new FemtoZip(outFileName);
}

OutputFileHelper::~OutputFileHelper()
{
	if (m_impl->mpOutfile)
		delete m_impl->mpOutfile;
	if (m_impl)
		delete m_impl;
}

bool OutputFileHelper::writeChildFile(const char *childFileName, const char *str)
{
	if (!m_impl->mpOutfile)
		return true;
	m_impl->mpOutfile->createEntry(childFileName, 0);
	if (m_impl->mpOutfile->errorCode())
		return false;
	m_impl->mpOutfile->writeString(str);
	if (m_impl->mpOutfile->errorCode())
		return false;
	m_impl->mpOutfile->closeEntry();
	if (m_impl->mpOutfile->errorCode())
		return false;
	return true;
}

bool OutputFileHelper::writeChildFile(const char *childFileName, const char *str, const char)
{
	if (!m_impl->mpOutfile)
		return true;
	m_impl->mpOutfile->createEntry(childFileName, 0); // only storing without compressing works with FemtoZip
	if (m_impl->mpOutfile->errorCode())
		return false;
	m_impl->mpOutfile->writeString(str);
	if (m_impl->mpOutfile->errorCode())
		return false;
	m_impl->mpOutfile->closeEntry();
	if (m_impl->mpOutfile->errorCode())
		return false;
	return true;
}

/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
